pub enum BadPixelMode {
Set {
value: f64,
},
Replace {
dx: i32,
dy: i32,
},
Median {
half_x: i64,
half_y: i64,
},
}Expand description
The correction mode for a bad pixel.
Variants
Set
Replace the pixel with a fixed value.
Replace
Replace the pixel by copying from a neighbor at relative offset (dx, dy).
Median
Replace the pixel with the median of a kernel. half_x/half_y are the
kernel half-extents (C++ medianCoordinate); the kernel spans
(2*half_x+1) x (2*half_y+1) pixels.