compress_zlib

Function compress_zlib 

pub fn compress_zlib(src: &NDArray) -> NDArray
Compress an NDArray using zlib (deflate).

Mirrors C++ compressZlib. The raw bytes of the data buffer are compressed with a zlib stream. The original data type ordinal is stored as an attribute so decompression can reconstruct the correct typed buffer.