decompress_zlib

Function decompress_zlib 

pub fn decompress_zlib(src: &NDArray) -> Option<NDArray>
Decompress a zlib-compressed NDArray.

Returns None if the codec is not Zlib or decompression fails. The original typed buffer is reconstructed using the stored data type attribute.