create_stats_runtime

Function create_stats_runtime 

pub fn create_stats_runtime(
    port_name: &str,
    pool: Arc<NDArrayPool>,
    queue_size: usize,
    ndarray_port: &str,
    wiring: Arc<WiringRegistry>,
    ts_registry: &TsReceiverRegistry,
) -> (PluginRuntimeHandle, Arc<Mutex<StatsResult>>, NDStatsParams, JoinHandle<()>)
Create a stats plugin runtime with an integrated time series port.

Returns: Create a stats plugin runtime. The TS receiver is stored in the registry for later pickup by NDTimeSeriesConfigure.